@@ -100,17 +100,7 @@ class UpnpRequester:
         body: Optional[str] = None,
         body_type: str = "text",
     ) -> Tuple[int, Mapping, Union[str, bytes, None]]:
-        """
-        Actually do a HTTP request.
-
-        :param method HTTP Method
-        :param url URL to call
-        :param headers Headers to send
-        :param body Body to send
-        :param body_type How to interpret body: 'text', 'raw', 'ignore'
-
-        :return status code, headers, body
-        """
+        """Actually do a HTTP request."""
         # pylint: disable=too-many-arguments
         raise NotImplementedError()
 
@@ -469,15 +459,13 @@ class UpnpAction:
         self,
         action_info: ActionInfo,
         arguments: List["UpnpAction.Argument"],
-        disable_unknown_out_argument_error: bool = False,
+        non_strict: bool = False,
     ) -> None:
         """Initialize."""
         self._action_info = action_info
         self._arguments = arguments
         self._service: Optional[UpnpService] = None
-        self._properties = {
-            "disable_unknown_out_argument_error": disable_unknown_out_argument_error,
-        }
+        self._non_strict = non_strict
 
     @property
     def name(self) -> str:
@@ -619,7 +607,7 @@ class UpnpAction:
     ) -> Mapping[str, Any]:
         """Parse response from called Action."""
         # pylint: disable=unused-argument
-        xml = DET.fromstring(response_body)
+        xml = DET.fromstring(response_body.rstrip(" \t\r\n\0"))
 
         query = ".//soap_envelope:Body/soap_envelope:Fault"
         if xml.find(query, NS):
@@ -643,6 +631,13 @@ class UpnpAction:
         args = {}
         query = ".//{{{0}}}{1}Response".format(service_type, self.name)
         response = xml.find(query, NS)
+
+        # Strip version number from service type to be more tolerant to incomplete namespace.
+        if response is None and ":" in service_type and self._non_strict:
+            service_type_funny = ":".join(service_type.split(":")[:-1])
+            query = ".//{{{0}}}{1}Response".format(service_type_funny, self.name)
+            response = xml.find(query, NS)
+
         if response is None:
             raise UpnpError(
                 "Invalid response: %s" % (ET.tostring(xml, encoding="unicode"),)
@@ -652,7 +647,7 @@ class UpnpAction:
             name = arg_xml.tag
             arg = self.argument(name, "out")
             if not arg:
-                if self._properties["disable_unknown_out_argument_error"]:
+                if self._non_strict:
                     continue
 
                 raise UpnpError(
